# -*- coding: utf-8 -*-
"""
    soil
    ~~~~

    :copyright: (c) 2012 by Natan Lao.
    :license: BSD, see LICENSE for more details.
"""
__version__ = '0.1.4-dev'
__all__ = ['core', 'extensions', 'serving', 'shovel', 'test', 'util']
